@@ -1,19 +1,19 @@
 import pytest
-from pyrsistent import pclass
+from pyrsistent import immutable
 
-class Empty(pclass(verbose=True)):
+class Empty(immutable(verbose=True)):
     pass
 
 
-class Single(pclass('x')):
+class Single(immutable('x')):
     pass
 
 
-class FrozenMember(pclass('x, y_')):
+class FrozenMember(immutable('x, y_')):
     pass
 
 
-class DerivedWithNew(pclass(['x', 'y'])):
+class DerivedWithNew(immutable(['x', 'y'])):
     def __new__(cls, x, y):
         return super(DerivedWithNew, cls).__new__(cls, x, y)
 
@@ -59,8 +59,9 @@ def test_cannot_replace_frozen_member():
     with pytest.raises(AttributeError):
         t.set(y_=18)
 
+
 def test_derived_class_with_new():
     d = DerivedWithNew(1, 2)
     d2 = d.set(x=3)
 
-    assert d2.x == 3
\ No newline at end of file
+    assert d2.x == 3
