@@ -90,7 +90,7 @@ def test_index_invalid_type():
     with pytest.raises(TypeError) as e:
         plist([1, 2, 3])['foo']  # type: ignore
 
-    assert 'cannot be interpreted' in str(e)
+    assert 'cannot be interpreted' in str(e.value)
 
 
 def test_slicing_take():
